# Changelog

All notable changes to this project will be documented in this file.

## 2.1.1 - 2022-07-03

- Fix TypeError() on loading objects after `pickle_compat.unpatch()`

## [2.1.0] - 2020-12-28

Add compatibility with Python 3.7 and 3.9

## [2.0.0] - 2020-06-18

Fall back to latin1 encoding when decoding python2.x strings in python3.x

## [1.0.0] - 2020-05-26

Released the first version of pickle-compat.
